hako library
Hako state management for Flutter.
Classes
- BaseHako
- Base abstract class for Hako state containers.
-
GetEvent<
T> - An event that represents the retrieval of a state value from a Hako container.
- Hako
- A container for multiple state objects.
- HakoEvent
- Base class for all events that can occur within a Hako state container.
-
HakoProvider<
H extends BaseHako> - A Provider widget that provides a specific Hako instance to its descendants and rebuilds dependents whenever a 'set' operation is correctly performed.
-
HakoStateEvent<
T> - Base class for events that involve state values in a Hako state container.
-
SetEvent<
T> - An event that represents the modification of a state value in a Hako container.
Mixins
- HakoEventStreamMixin
- A mixin that provides event streaming capabilities for Hako events.
Extensions
- HakoBuildContextExtension on BuildContext
- Extension methods on BuildContext for accessing and watching Hako state containers.
- HakoStateKeyExtension on HakoStateKey
- Extension on HakoStateKey that provides convenient access to key properties.
Typedefs
- HakoStateKey = (Type, String?)
- A key for uniquely identifying state values in a Hako state container.
-
RegisterCallback
= void Function<
T>(T value, {String? name}) - A callback function for registering initial state values in a Hako state container.
Exceptions / Errors
-
HakoProviderNotFoundException<
H extends BaseHako> - Exception thrown when a HakoProvider of a specific type is not found in the widget tree.